@@ -1,26 +1,26 @@
 package Devel::Git::MultiBisect;
 use strict;
 use warnings;
-use v5.14.0;
-use Devel::Git::MultiBisect::Init;
+use v5.10.0;
+use Devel::Git::MultiBisect::Opts qw( process_options );
 use Devel::Git::MultiBisect::Auxiliary qw(
     clean_outputfile
     hexdigest_one_file
     validate_list_sequence
+    get_current_branch
 );
 use Carp;
-use Config;
 use Cwd;
 use File::Spec;
 use File::Temp;
 use List::Util qw(sum);
+use Data::Dump qw( pp );
 
-our $VERSION = '0.15_002';
-$VERSION =~ tr/_//d;
+our $VERSION = '0.01';
 
 =head1 NAME
 
-Devel::Git::MultiBisect - Study build and test output over a range of F<git> commits
+Devel::Git::MultiBisect - Study test output over a range of F<git> commits
 
 =head1 SYNOPSIS
 
@@ -55,16 +55,15 @@ parent package may be called from either child class.
 
 Given a Perl library or application kept in F<git> for version control, it is
 often useful to be able to compare the output collected from running one or
-more test files over a range of F<git> commits.  If that range is sufficiently
+several test files over a range of F<git> commits.  If that range is sufficiently
 large, a test may fail in B<more than one way> over that range.
 
 If that is the case, then simply asking, I<"When did this file start to
-fail?"> -- a question which C<git bisect> is designed to answer -- is
-insufficient.  In order to identify more than one point of failure, we may
-need to (a) capture the test output for each commit; or, (b) capture the test
-output only at those commits where the output changed.  The output of a run of
-a test file may change for a variety of reasons:  test failures, segfaults,
-changes in the number or content of tests, etc.
+fail?"> is insufficient.  We may want to (a) capture the test output for each
+commit; or, (b) capture the test output only at those commits where the output
+changed.  The output of a run of a test file may change for a variety of
+reasons:  test failures, segfaults, changes in the number or content of tests,
+etc.)
 
 F<Devel::Git::MultiBisect> provides methods to achieve that objective.  Its
 child classes, F<Devel::Git::MultiBisect::AllCommits> and
@@ -78,9 +77,8 @@ documentation for further discussion.
 
 =item * B<commit>
 
-A source code change set entered ("committed") to a F<git> repository.  Each
-commit is denoted by a SHA.  In this library, whenever a commit is called for
-as the argument to a function, you can also use a F<git tag>.
+An individual commit to a F<git> repository as denoted by a SHA.  When a commit is
+called for as the argument to a function, you can also use a F<git tag>.
 
 =item * B<commit range>
 
@@ -93,9 +91,7 @@ A test file from the test suite of the application or library under study.
 =item * B<test output>
 
 What is sent to STDOUT or STDERR as a result of calling a test program such as
-F<prove> or F<t/harness> on an individual target file.  Currently we assume
-that all such test programs are written based on the
-L<Test Anything Protocol (TAP)|https://en.wikipedia.org/wiki/Test_Anything_Protocol>.
+F<prove> or F<t/harness> on an individual target file.
 
 =item * B<transitional commit>
 
@@ -165,10 +161,58 @@ Object of Devel::Git::MultiBisect child class.
 
 sub new {
     my ($class, $params) = @_;
+    my %data;
 
-    my $data = Devel::Git::MultiBisect::Init::init($params);
+    while (my ($k,$v) = each %{$params}) {
+        $data{$k} = $v;
+    }
 
-    return bless $data, $class;
+    my @missing_dirs = ();
+    for my $dir ( qw| gitdir workdir outputdir | ) {
+        push @missing_dirs, $data{$dir}
+            unless (-d $data{$dir});
+    }
+    if (@missing_dirs) {
+        croak "Cannot find directory(ies): @missing_dirs";
+    }
+
+    $data{last_short} = substr($data{last}, 0, $data{short});
+    $data{commits} = _get_commits(\%data);
+    $data{targets} //= [];
+    $data{commit_counter} = 0;
+
+    return bless \%data, $class;
+}
+
+sub _get_commits {
+    my $dataref = shift;
+    my $cwd = cwd();
+    chdir $dataref->{gitdir} or croak "Unable to chdir";
+    my @commits = ();
+    my ($older, $cmd);
+    my ($fh, $err) = File::Temp::tempfile();
+    if ($dataref->{last_before}) {
+        $older = '^' . $dataref->{last_before};
+        $cmd = "git rev-list --reverse $older $dataref->{last} 2>$err";
+    }
+    else {
+        $older = $dataref->{first} . '^';
+        $cmd = "git rev-list --reverse ${older}..$dataref->{last} 2>$err";
+    }
+    chomp(@commits = `$cmd`);
+    if (! -z $err) {
+        open my $FH, '<', $err or croak "Unable to open $err for reading";
+        my $error = <$FH>;
+        chomp($error);
+        close $FH or croak "Unable to close $err after reading";
+        croak $error;
+    }
+    my @extended_commits = map { {
+        sha     => $_,
+        short   => substr($_, 0, $dataref->{short}),
+    } } @commits;
+    chdir $cwd or croak "Unable to return to original directory";
+    return [ @extended_commits ];
 }
 
 =head2 C<get_commits_range()>
@@ -461,26 +505,17 @@ sub run_test_files_on_one_commit {
     return $outputsref;
 }
 
-sub _configure_one_commit {
+sub _configure_build_one_commit {
     my ($self, $commit) = @_;
     chdir $self->{gitdir} or croak "Unable to change to $self->{gitdir}";
     system(qq|git clean --quiet -dfx|) and croak "Unable to 'git clean --quiet -dfx'";
-    my $starting_branch = $self->{branch};
+    my $starting_branch = get_current_branch();
 
     system(qq|git checkout --quiet $commit|) and croak "Unable to 'git checkout --quiet $commit'";
     say "Running '$self->{configure_command}'" if $self->{verbose};
     system($self->{configure_command}) and croak "Unable to run '$self->{configure_command})'";
-    return $starting_branch;
-}
-
-sub _configure_build_one_commit {
-    my ($self, $commit) = @_;
-
-    my $starting_branch = $self->_configure_one_commit($commit);
-
     say "Running '$self->{make_command}'" if $self->{verbose};
     system($self->{make_command}) and croak "Unable to run '$self->{make_command})'";
-
     return $starting_branch;
 }
 
@@ -507,7 +542,7 @@ sub _test_one_commit {
             $cmd = qq|cd t; ./perl harness -v $target->{path} >$outputfile 2>&1; cd -|;
         }
         say "Running '$cmd'" if $self->{verbose};
-        system($cmd) and Carp::confess("Unable to run test_command <$cmd> on $Config{myuname}");
+        system($cmd) and croak "Unable to run test_command";
         $outputfile = clean_outputfile($outputfile);
         push @outputs, {
             commit => $commit,
@@ -521,36 +556,6 @@ sub _test_one_commit {
     return \@outputs;
 }
 
-sub _bisection_decision {
-    my ($self, $target_h_md5_hex, $current_start_md5_hex, $h, $relevant_self,
-        $overall_end_md5_hex, $current_start_idx, $current_end_idx, $max_idx, $n) = @_;
-    if ($target_h_md5_hex ne $current_start_md5_hex) {
-        my $g = $h - 1;
-        $self->_run_one_commit_and_assign($g);
-        my $target_g_md5_hex  = $relevant_self->[$g]->{md5_hex};
-        if ($target_g_md5_hex eq $current_start_md5_hex) {
-            if ($target_h_md5_hex eq $overall_end_md5_hex) {
-            }
-            else {
-                $current_start_idx  = $h;
-                $current_end_idx    = $max_idx;
-            }
-            $n++;
-        }
-        else {
-            # Bisection should continue downwards
-            $current_end_idx = $h;
-            $n++;
-        }
-    }
-    else {
-        # Bisection should continue upwards
-        $current_start_idx = $h;
-        $n++;
-    }
-    return ($current_start_idx, $current_end_idx, $n);
-}
-
 =head2 C<get_timings()>
 
 =over 4
@@ -569,15 +574,29 @@ Hash reference.  The selection of elements in this hashref will depend on
 which subclass of F<Devel::Git::MultiBisect> you are using and may differ among
 subclasses.  Example:
 
-    { elapsed => 4297, mean => 186.83, runs => 23 }
 
-In this example (taken from a run of one test file over 220 commits in Perl 5
-blead), 23 runs were needed to achieve a result.   These took 4297 seconds
-(approximately 71 minutes) with a mean run time of approximately 3 minutes
-each.
+Will return undefined value if not yet available in the object.
 
-Method will return undefined value if timings are not yet available within the
-object.
+=over 4
+
+=item * C<path>
+
+Absolute paths to the test files selected for examination.  Test file is
+tested for its existence.
+
+=item * C<stub>
+
+String composed by taking an element in the array ref passed as argument and
+substituting underscores C(<_>) for forward slash (C</>) and dot (C<.>)
+characters.  So,
+
+    t/44_func_hashes_mult_unsorted.t
+
+... becomes:
+
+    t_44_func_hashes_mult_unsorted_t
+
+=back
 
 =back
 
@@ -599,7 +618,7 @@ or through the web interface at L<http://rt.cpan.org>.
 James E. Keenan (jkeenan at cpan dot org).  When sending correspondence, please
 include 'Devel::Git::MultiBisect' or 'Devel-Git-MultiBisect' in your subject line.
 
-Creation date:  October 12 2016. Last modification date:  December 06 2019.
+Creation date:  November 01 2016. Last modification date:  November 01 2016.
 
 Development repository: L<https://github.com/jkeenan/devel-git-multibisect>
 
@@ -615,17 +634,13 @@ For naming suggestion: L<http://www.nntp.perl.org/group/perl.module-authors/2016
 
 =item * Ricardo Signes
 
-For feedback during initial development.
-
-=item * Eily and Monk::Thomas
-
-For diagnosis of regex problems in http://perlmonks.org/?node_id=1175983.
+For feedback during inital development.
 
 =back
 
 =head1 COPYRIGHT
 
-Copyright (c) 2016-2019 James E. Keenan.  United States.  All rights reserved.
+Copyright (c) 2016 James E. Keenan.  United States.  All rights reserved.
 This is free software and may be distributed under the same terms as Perl
 itself.
 
