@@ -1,7 +1,7 @@
 package Devel::Git::MultiBisect::AllCommits;
 use strict;
 use warnings;
-use v5.14.0;
+use v5.10.0;
 use parent( qw| Devel::Git::MultiBisect | );
 use Devel::Git::MultiBisect::Opts qw( process_options );
 use Devel::Git::MultiBisect::Auxiliary qw(
@@ -13,9 +13,9 @@ use Carp;
 use Cwd;
 use File::Temp;
 use List::Util qw(first sum);
+#use Data::Dump qw( pp );
 
-our $VERSION = '0.15_002';
-$VERSION =~ tr/_//d;
+our $VERSION = '0.01';
 
 =head1 NAME
 
@@ -197,14 +197,9 @@ sub run_test_files_on_all_commits {
 	    elapsed	=> $end_time - $start_time,
 	    runs	=> scalar(@{$all_commits}),
     );
-    if ($timings{runs}) {
-        $timings{mean} = sprintf("%.02f" => $timings{elapsed} / $timings{runs});    }
+    $timings{mean} = sprintf("%.02f" => $timings{elapsed} / $timings{runs});
     if ($self->{verbose}) {
-        my $msg = "Ran $timings{runs} runs; elapsed: $timings{elapsed} sec";
-        if ($timings{runs}) {
-            $msg .= "; mean: $timings{mean} sec";
-        }
-        say $msg;
+        say "Ran $timings{runs} runs; elapsed: $timings{elapsed} sec; mean: $timings{mean} sec";
     }
     $self->{all_outputs}  = [ @all_outputs ];
     $self->{timings}	  = \%timings;
