@@ -1,15 +1,13 @@
 package Devel::Git::MultiBisect::Opts;
 use strict;
 use warnings;
-use v5.14.0;
-our $VERSION = '0.15_002';
-$VERSION =~ tr/_//d;
+use v5.10.0;
+our $VERSION = '0.01';
 use base qw( Exporter );
 our @EXPORT_OK = qw(
     process_options
 );
 use Carp;
-use Config;
 use Cwd;
 use Data::Dumper;
 use File::Path qw( mkpath );
@@ -61,12 +59,9 @@ sub process_options {
         croak "Value of 'targets' must be an array reference"
             unless ref($args{targets}) eq 'ARRAY';
     }
-    my $found_make = $Config{make};
     if ($args{verbose}) {
         print "Arguments provided to process_options():\n";
         print Dumper \%args;
-        print "\n";
-        print q|For 'make', %Config has: |, $found_make, "\n";
     }
 
     my %defaults = (
@@ -76,7 +71,7 @@ sub process_options {
        'branch' => 'master',
        'verbose' => 0,
        'configure_command' => 'perl Makefile.PL 1>/dev/null',
-       'make_command' => "$found_make 1>/dev/null",
+       'make_command' => 'make 1>/dev/null',
        'test_command' => 'prove -vb',
    );
 
