@@ -1,7 +1,7 @@
 package Devel::Git::MultiBisect::Transitions;
 use strict;
 use warnings;
-use v5.14.0;
+use v5.10.0;
 use parent ( qw| Devel::Git::MultiBisect | );
 use Devel::Git::MultiBisect::Opts qw( process_options );
 use Devel::Git::MultiBisect::Auxiliary qw(
@@ -13,9 +13,9 @@ use Carp;
 use Cwd;
 use File::Temp;
 use List::Util qw(first sum);
+#use Data::Dump qw( pp );
 
-our $VERSION = '0.15_002';
-$VERSION =~ tr/_//d;
+our $VERSION = '0.01';
 
 =head1 NAME
 
@@ -70,7 +70,7 @@ you can use another package in this library, F<Devel::Git::MultiBisect::AllCommi
 =head1 METHODS
 
 This package inherits methods from F<Devel::Git::MultiBisect>.  Only methods unique to
-F<Devel::Git::MultiBisect::Transitions> are documented here.  See the documentation for
+F<Devel::Git::MultiBisect::AllCommits> are documented here.  See the documentation for
 F<Devel::Git::MultiBisect> for all other methods, including:
 
     new()
@@ -309,13 +309,30 @@ sub _multisect_one_target {
         #         index j   has a different md5_hex, we have to do a run on
         #         j-1 as well.
 
-        ($current_start_idx, $current_end_idx, $n) =
-            $self->_bisection_decision(
-                $target_h_md5_hex, $current_start_md5_hex, $h,
-                $self->{multisected_outputs}->{$stub},
-                $overall_end_md5_hex, $current_start_idx, $current_end_idx,
-                $max_idx, $n,
-            );
+        if ($target_h_md5_hex ne $current_start_md5_hex) {
+            my $g = $h - 1;
+            $self->_run_one_commit_and_assign($g);
+            my $target_g_md5_hex  = $self->{multisected_outputs}->{$stub}->[$g]->{md5_hex};
+            if ($target_g_md5_hex eq $current_start_md5_hex) {
+                if ($target_h_md5_hex eq $overall_end_md5_hex) {
+                }
+                else {
+                    $current_start_idx  = $h;
+                    $current_end_idx    = $max_idx;
+                }
+                $n++;
+            }
+            else {
+                # Bisection should continue downwards
+                $current_end_idx = $h;
+                $n++;
+            }
+        }
+        else {
+            # Bisection should continue upwards
+            $current_start_idx = $h;
+            $n++;
+        }
         $this_target_status = $self->_evaluate_status_one_target_run($target_idx);
     }
     return 1;
@@ -323,6 +340,7 @@ sub _multisect_one_target {
 
 sub _evaluate_status_one_target_run {
     my ($self, $target_idx) = @_;
+    my $stub = $self->{targets}->[$target_idx]->{stub};
     my @trans = ();
     for my $o (@{$self->{all_outputs}}) {
         push @trans,
